#!/bin/bash

LANG=C
set -u
#
# dnsbl-check-standalone.sh
#
# By Damon Tajeddini (dta)
# # 10.03.2009 , heise
# 
# als nagios-plugin rbe Sep. 2009
# geandert Juni 2011, rbe
#
#MAIL_RCPT="lihas@lihas.de"

. /usr/lib/nagios/plugins/utils.sh


DNSBLlist=`grep -v ^# <<!
rbl2.triumf.ca
dnsrbl.swinog.ch
rbl.swinog.ch
cbl.anti-spam.org.cn
cblplus.anti-spam.org.cn
cdl.anti-spam.org.cn
dnsbl.burnt-tech.com
bogons.cymru.com
0spam.fusionzero.com
dyna.spamrats.com
noptr.spamrats.com
spam.spamrats.com
psbl.surriel.com
bl.tiopan.com
ubl.unsubscore.com
all.bl.blocklist.de
dnsbl.inps.de
relays.bl.kundenserver.de
spamsources.fabel.dk
no-more-funn.moensted.dk
#bl.technovision.dk
db.wpbl.info
all.rbl.jp
url.rbl.jp
truncate.gbudb.net
dnsbl.kempt.net
spamguard.leadmon.net
bl.mailspike.net
ix.dnsbl.manitu.net
relays.nether.net
unsure.nether.net
korea.services.net
dnsbl.sorbs.net
bl.spamcop.net
bl.spameatingmonkey.net
dnsbl-1.uceprotect.net
dnsbl-2.uceprotect.net
dnsbl-3.uceprotect.net
virbl.dnsbl.bit.nl
cbl.abuseat.org
dnsbl.ahbl.org
ircbl.ahbl.org
ips.backscatterer.org
b.barracudacentral.org
bl.emailbasura.org
bhnc.njabl.org
combined.njabl.org
dnsbl.njabl.org
access.redhawk.org
bl.spamcannibal.org
pbl.spamhaus.org
sbl.spamhaus.org
xbl.spamhaus.org
dul.ru
tor.dan.me.uk
!`

# reverse IP address bytes
convertIP()
{
 set `IFS=".";echo $1`
 echo $4.$3.$2.$1
}

usage()
{
 echo "Usage: $0 [-H &lt;host&gt;|-p]"
 echo " -H IP address to check"
 echo " -F FQDN to check"
 echo " -p Print list of DNSBLs"
 echo " -t check for timeout "
 exit 3
}

# Checks the IP with list of DNSBL servers
check()
{
 ret_value=$STATE_OK
 blacklisted=""
 for i in $DNSBLlist
 do
   if dig $ip_arpa.$i +short | grep -q "^127.0.0."
   then
     ret_value=$STATE_CRITICAL
     blacklisted+="$i, "
   fi
 done
 # Sonderfall hostkarma.junkemailfilter.com wg. reply-code
 if dig $ip_arpa.hostkarma.junkemailfilter.com +short | grep -q "^127.0.0.2"
 then
   ret_value=$STATE_CRITICAL
   blacklisted+="hostkarma.junkemailfilter.com, "
 fi
# Sonderfall list.quorum.to wg. reply-code
 if dig $ip_arpa.list.quorum.to +short | grep -q "^127.0.0.[245]"
 then
    ret_value=$STATE_CRITICAL
    blacklisted+="list.quorum.to, "
 fi

# IP.v4BL.org nachfolger von DDNSBL.InternetDefenseSystems.com
 if dig $ip_arpa.IP.v4BL.org +short | grep -q "^127.0.0.2"
 then
    ret_value=$STATE_CRITICAL
    blacklisted+="IP.v4BL.org, "
 fi

 blacklisted=${blacklisted%, }
 if [ "$ret_value" = "$STATE_OK" ]; then 
   echo  "DNSBL OK for $ip" 
 else
   echo  "$ip blacklisted on: $blacklisted"
 fi
 exit $ret_value
} # check

check_timeout () {
 to_listed=''
 for i in $DNSBLlist IP.v4BL.org list.quorum.to hostkarma.junkemailfilter.com
 do
   if dig $ip_arpa.$i +short | grep -q 'connection timed out'
   then
     to_listed+="$i, "
   fi
 done
 if [ -n "$to_listed" ]; then
   echo "query $ip timed out for: $to_listed"
 else
   echo "no blacklist query timed out"
 fi
}

case $1 in
 -H)
 if [ -z "$2" ]; then
   echo "ip address missing"
   exit $STATE_UNKNOWN
 fi
 ip=$2
 ip_arpa=`convertIP $ip`
 check;;

 -p)
 for i in $DNSBLlist
 do
 echo $i
 done
 exit $STATE_UNKNOWN;;

 -t)
 # check for timeout
  ip='127.0.0.2'
  ip_arpa=`convertIP $ip`
  check_timeout
 ;;

 --help)
 usage
 exit;;

 *)
 if [ -z "$1" ]; then
 usage
 fi
 echo "unknown command: $1"
 exit $STATE_UNKNOWN;;
esac
