#! /bin/bash

# Roland Becker <lihas@lihas.de>, Nov. 2012
set -u

CRITSIZE=2G
WARNSIZE=1G
#DIR_FILE="/usr/lib/nagios/plugins/lihas/`basename $0 .sh`.files"
DIR_FILE=""
DIRS=""
ERRORFILE="/tmp/`basename $0 .sh`.err"
rm -f $ERRORFILE

. `dirname $0`/../utils.sh

usage () {
	echo "usage: `basename $0` [ -c size ] [ -w size ] {-f filename | -d directory}"
	echo "size in kilobytes"
	exit $STATE_UNKOWN
}

while [ $# -gt 0 ]; do
	case "$1" in
		-c)	shift
			CRITSIZE=$1
		;;
		-w) shift
			WARNSIZE=$1
		;;
		-f) shift
			DIR_FILE=$1
		;;
		-d) shift
			DIRS+=" $1"
		;;
		*) usage
	esac
	shift
done 

for v in CRITSIZE WARNSIZE; do
	case "${!v}" in
		*G) declare -i $v=$((${!v%G}*1024*1024))
		;;
		*M) declare -i $v=$((${!v%M}*1024))
		;;
	esac
done

critdirs=""
warndirs=""

if [ -n "$DIR_FILE" ] ; then
	if [ -r "$DIR_FILE" ] ; then
		DIRS=`cat $DIR_FILE`
	else
		echo "$DIR_FILE not readable"
		exit $STATE_UNKNOWN
	fi
fi
if [ -z "$DIRS" ]; then
	echo "no directorys specified"
	exit $STATE_UNKNOWN
fi
while read size name; do
	if ((size > CRITSIZE)) ;then
		critdirs+=" $name"
	elif ((size > WARNSIZE)) ; then
		warndirs+=" $name"
	fi
done < <(du -sk $DIRS 2>$ERRORFILE)
chown nagios $ERRORFILE


exitstatus=$STATE_OK
if [ -n "$critdirs" ] ; then
	echo "$critdirs"
	[ -n "$warndirs" ] && echo "warning: $warndirs"
	exitstatus=$STATE_CRITICAL
elif [ -n "$warndirs" ]; then
	echo "$warndirs"
	exitstatus=$STATE_WARNING
fi
if [ -s $ERRORFILE ]; then
	echo "'Errors: `cat $ERRORFILE`"
	exitstatus=$STATE_CRITICAL
fi
if [ $exitstatus = $STATE_OK ] ;then
	echo "all dirs ok"
fi

exit $exitstatus
